==> galette-0.7.5.3.tar.bz2: galette-0.7.5.3/tests/coverage.php <==
<?php


/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Atoum code coverage in HTML format.
 * To use it, you can choose either:
 *  * php path/to/test/file -c path/to/this/file
 *  * php path/to/atoum/scripts/runner.php -c path/to/this/file -f path/to/test/file
 *
 * PHP version 5
 *
 * Copyright © 2007-2013 The Galette Team
 *
 * This file is part of Galette (http://galette.tuxfamily.org).
 *
 * Galette is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Galette is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Core
 * @package   GaletteTests
 *
 * @author    Johan Cwiklinski <johan@x-tnd.be>
 * @copyright 2013 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @version   SVN: $Id$
 * @link      http://galette.tuxfamily.org
 * @since     2013-01-13
 */

use \mageekguy\atoum;

$coverageField = new atoum\report\fields\runner\coverage\html(
    'Galette',
    __DIR__ . '/coverage'
);

$coverageField->setRootUrl(
    'file://' . realpath(__DIR__ . '/coverage/')
);

$script
    ->addDefaultReport()
    ->addField($coverageField);

==> galette-0.9.4.1.tar.bz2: galette-0.9.4.1/tests/coverage.php <==
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Atoum code coverage in HTML format.
 * To use it, you can choose either:
 *  * php path/to/test/file -c path/to/this/file
 *  * php path/to/atoum/scripts/runner.php -c path/to/this/file -f path/to/test/file
 *
 * PHP version 5
 *
 * Copyright © 2007-2014 The Galette Team
 *
 * This file is part of Galette (http://galette.tuxfamily.org).
 *
 * Galette is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Galette is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Core
 * @package   GaletteTests
 *
 * @author    Johan Cwiklinski <johan@x-tnd.be>
 * @copyright 2013-2014 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @version   SVN: $Id$
 * @link      http://galette.tuxfamily.org
 * @since     2013-01-13
 */

use mageekguy\atoum;

$coverageField = new atoum\report\fields\runner\coverage\html(
    'Galette',
    __DIR__ . '/coverage'
);

$coverageField->setRootUrl(
    'file://' . realpath(__DIR__ . '/coverage/')
);

$script
    ->addDefaultReport()
    ->addField($coverageField);
